==> style-o-matic-1.1.5.tgz: package/es/components/Tabs/Tabs.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import classNames from "classnames";
import { CoreComponent, setPropDefaultsAutoId, setPropTypesA11y, getValidProps, ROLE } from "../../lib";
import TabContent from "./TabContent.js";
import TabToggle from "./TabToggle.js";
import "./Tabs.css";

var Tabs = (_temp = _class = function (_CoreComponent) {
  _inherits(Tabs, _CoreComponent);

  function Tabs(props, context) {
    _classCallCheck(this, Tabs);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props, context));

    _initialiseProps.call(_this);

    _this.state = { activeTab: props.id + "_tab_1" };
    return _this;
  }

  Tabs.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        id = _getValidProps.id,
        uiclass = _getValidProps.uiclass,
        disabled = _getValidProps.disabled,
        smart = _getValidProps.smart,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var tabCount = 0;
    var contentCount = 0;

    return React.createElement(
      Component,
      props,
      React.createElement(
        "div",
        { className: "ui-tabs-tab-wrapper" },
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.TABTOGGLE) {
            tabCount += 1;
            return _this2.renderToggle(child, tabCount, id, inherited);
          }
          return null;
        })
      ),
      React.createElement(
        "div",
        { className: "ui-tabs-content-wrapper" },
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.TABCONTENT) {
            contentCount += 1;
            return _this2.renderContent(child, contentCount, id, inherited);
          }
          return null;
        })
      )
    );
  };

  return Tabs;
}(CoreComponent), _class.propTypes = setPropTypesA11y({
  smart: "bool",
  onSwitch: "func"
}), _class.defaultProps = setPropDefaultsAutoId({
  renderAs: "div",
  uirole: ROLE.TABS,
  smart: false,
  onSwitch: null
}), _class.Tab = TabToggle, _class.Content = TabContent, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleClick = function (event) {
    event.preventDefault();
    if (_this3.props.disabled) {
      return;
    }
    var id = event.target.attributes.id;

    _this3.setState({ activeTab: id.value });
    _this3.toggleSwitch(event);
  };

  this.toggleSwitch = function (event) {
    if (_this3.props.disabled) {
      return;
    }
    if (_this3.props.onSwitch) {
      _this3.props.onSwitch(event);
    }
  };

  this.renderToggle = function (child, index, parentId, _ref) {
    var props = _objectWithoutProperties(_ref, []);

    var id = parentId + "_tab_" + index;
    var activeClass = _this3.state.activeTab === id ? "tab active" : "tab";
    return cloneElement(child, _extends({}, props, {
      ref: child.ref,
      id: id,
      uiclass: _this3.childPrefix(activeClass),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleClick)
    }));
  };

  this.renderContent = function (child, index, parentId, _ref2) {
    var props = _objectWithoutProperties(_ref2, []);

    var id = parentId + "_tab_" + index;
    var activeClass = _this3.state.activeTab === id ? "content active" : "content";
    id += "_content";
    return cloneElement(child, _extends({}, props, {
      ref: child.ref,
      id: id,
      uiclass: _this3.childPrefix(activeClass)
    }));
  };
}, _temp);


export default Tabs;

==> style-o-matic-1.1.37.tgz: package/es/components/Tabs/Tabs.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import classNames from "classnames";
import { CoreComponent, getPropDefaultsAutoId, getPropTypesA11y, getValidProps, ROLE } from "../../lib";
import TabContent from "./TabContent.js";
import TabToggle from "./TabToggle.js";
import "./Tabs.css";

var Tabs = (_temp = _class = function (_CoreComponent) {
  _inherits(Tabs, _CoreComponent);

  function Tabs(props, context) {
    _classCallCheck(this, Tabs);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props, context));

    _initialiseProps.call(_this);

    _this.state = { activeTab: props.id + "_tab_1" };
    return _this;
  }

  Tabs.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        id = _getValidProps.id,
        uiclass = _getValidProps.uiclass,
        disabled = _getValidProps.disabled,
        smart = _getValidProps.smart,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var tabCount = 0;
    var contentCount = 0;

    return React.createElement(
      Component,
      props,
      React.createElement(
        "div",
        { className: "ui-tabs-tab-wrapper" },
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.TABTOGGLE) {
            tabCount += 1;
            return _this2.renderToggle(child, tabCount, id, inherited);
          }
          return null;
        })
      ),
      React.createElement(
        "div",
        { className: "ui-tabs-content-wrapper" },
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.TABCONTENT) {
            contentCount += 1;
            return _this2.renderContent(child, contentCount, id, inherited);
          }
          return null;
        })
      )
    );
  };

  return Tabs;
}(CoreComponent), _class.propTypes = getPropTypesA11y({
  smart: "bool",
  onSwitch: "func"
}), _class.defaultProps = getPropDefaultsAutoId({
  renderAs: "div",
  uirole: ROLE.TABS,
  smart: false,
  onSwitch: null
}), _class.Tab = TabToggle, _class.Content = TabContent, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleClick = function (event) {
    event.preventDefault();
    if (_this3.props.disabled) {
      return;
    }
    var id = event.target.attributes.id;

    _this3.setState({ activeTab: id.value });
    _this3.toggleSwitch(event);
  };

  this.toggleSwitch = function (event) {
    if (_this3.props.disabled) {
      return;
    }
    if (_this3.props.onSwitch) {
      _this3.props.onSwitch(event);
    }
  };

  this.renderToggle = function (child, index, parentId, _ref) {
    var props = _objectWithoutProperties(_ref, []);

    var id = parentId + "_tab_" + index;
    var activeClass = _this3.state.activeTab === id ? "tab active" : "tab";
    return cloneElement(child, _extends({}, props, {
      ref: child.ref,
      id: id,
      uiclass: _this3.childPrefix(activeClass),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleClick)
    }));
  };

  this.renderContent = function (child, index, parentId, _ref2) {
    var props = _objectWithoutProperties(_ref2, []);

    var id = parentId + "_tab_" + index;
    var activeClass = _this3.state.activeTab === id ? "content active" : "content";
    id += "_content";
    return cloneElement(child, _extends({}, props, {
      ref: child.ref,
      id: id,
      uiclass: _this3.childPrefix(activeClass)
    }));
  };
}, _temp);


export default Tabs;
